#' r from t-test 
#'
#'The t-value and total sample size are used to compute the effect size. 
#'@param t     T-test value
#'@param N     Total sample size of the study
#'@return Effect size  (ESr)
#'@return Fisher's transformed effect size r  (ESzr)
#'@return Variance for the Fisher's transformed r (Var)
#'@examples
#'ESrT (-1.8, 200)
#'@export
ESrT <- function(t, N)
{
  ESr <- t/(sqrt((t^2)+N-2))
  ESzr <-.50*(log((1+ESr)/(1-ESr)))
  SEzr <-1/(sqrt(N-3))  
  VARzr <-SEzr^2
  return (setNames((list(ESr, ESzr, VARzr)),c("Effect Size", "Fisher's transformed r", "Variance")))
}

#' r from Chi-square test 
#'
#'The Chi-square value and total sample size are used to compute the effect size. 
#'@param  X2    Chi-square value
#'@param  N     Total sample size of the study
#'@return Effect size  (ESr)
#'@return Fisher's transformed effect size r  (ESzr)
#'@return Variance for the Fisher's transformed r (Var)
#'@examples
#'ESrX (3.841, 200)
#'@export
ESrX <- function(X2, N)
{
  ESr <- sqrt((X2/N))
  ESzr <-.50*(log((1+ESr)/(1-ESr)))
  SEzr <-1/(sqrt(N-3)) 
  VARzr <-SEzr^2
  return (setNames((list(ESr, ESzr, VARzr)),c("Effect Size", "Fisher's transformed r", "Variance")))
}

#' r from exact p-value from a t-test 
#'
#' The exact p-value is used to estimate the t value. Then the t-value and sample size are used to compute the effect size.
#'@param pvalue    The reported exact p-value 
#'@param df        Degrees of frredom
#'@param N         Total sample size 
#'@param tail      Direction of the tail (1 = 1-tail, 2 = 2-tail, 3 = error)
#'@return Effect size  (ESr)
#'@return Fisher's transformed effect size r  (ESzr)
#'@return Variance for the Fisher's transformed r (Var)
#'@examples
#'ESrExpT (0.04, 98, 100, 2)
#'@export
ESrExpT <- function(pvalue, df, N, tail)
{
  if (tail == 1) {T<- qt(pvalue,df)}
  else if(tail == 2) {T <-qt(pvalue/2,df)}
  else {ESr <-'Error'
        return (ESr)}
  ESr <- T/(sqrt((T^2)+(N-2)))
  ESzr <-.50*(log((1+ESr)/(1-ESr)))
  SEzr <-1/(sqrt(N-3))  
  VARzr <-SEzr^2
  return (setNames((list(ESr, ESzr, VARzr)),c("Effect Size", "Fisher's transformed r", "Variance")))
}

#' r from exact p-value from a Chi-square test 
#'
#' The exact p-value is used to estimate the Chi-square value. Then the Chi-square value and sample size are used to compute the effect size.
#'@param pvalue   The reported exact p-value 
#'@param df       Degrees of frredom
#'@param N        Total sample size 
#'@return Effect size  (ESr)
#'@return Fisher's transformed effect size r  (ESzr)
#'@return Variance for the Fisher's transformed r (Var)
#'@examples
#'ESrExpX (0.04, 1, 200)
#'@export
ESrExpX <-function(pvalue, df, N) 
{
  X <- qchisq(1-pvalue, df, ncp = 0, lower.tail = TRUE)
  ESr <- sqrt((X/N))
  ESzr <-.50*(log((1+ESr)/(1-ESr)))
  SEzr <-1/(sqrt(N-3))  
  VARzr <-SEzr^2
  return (setNames((list(ESr, ESzr, VARzr)),c("Effect Size", "Fisher's transformed r", "Variance")))
}
