#' r to Cohen's d
#'
#' Converting r to Cohen's d.
#'@param r    Correlation coefficient (effect size)
#'@return     Cohen's d effect size
#'@examples
#'ESr2d (0.3)
#'@export
ESr2d <- function(r)
{
  ESd <- ((2*r)/(sqrt((1-(r^2)))))
  return (setNames((list(ESd)), c("Cohen's d")))
}

#' r to Hedges's g
#'
#'Converting r to Hedges's g
#'@param  r     Correlation coefficient (effect size)
#'@param  n1    Sample size of Group 1
#'@param  n2    Sample size of Group 2
#'@param  df    Degrees of freedom (n1+n2)-2))
#'@return       Hedges's g effect size
#'@examples
#'ESr2g (0.3, 10, 10, 18)
#'@export
ESr2g <- function(r, n1, n2, df)
{
  ESg <- ((r/(sqrt((1-(r^2)))))*(sqrt((df*(n1+n2))/(n1*n2))))
  return (setNames((list(ESg)), c("Hedges's g")))
}

#'Cohen's d to Hedges's g
#'
#'Converting Cohen's d to Hedges's g
#'@param  d     Cohen's d (effect size)
#'@param  n1    Sample size of Group 1
#'@param  n2    Sample size of Group 2
#'@param  df    Degrees of freedom (n1+n2)-2))
#'@return       Hedges's g effect size
#'@examples
#'ESd2g (0.307, 10, 11, 19)
#'@export
ESd2g <- function(d, n1, n2, df)
{
  ESg <-(d/((sqrt(((n1 + n2)/df)))))
  return (setNames((list(ESg)), c("Hedges's g")))
}

#' Hedges's g to Cohen's d
#'
#'Converting Hedges's g to Cohen's d
#'@param  g     Hedges's g (effect size)
#'@param  n1    Sample size of Group 1
#'@param  n2    Sample size of Group 2
#'@param  df    Degrees of freedom (n1+n2)-2))
#'@return       Hedges's g effect size
#'@examples
#'ESg2d (0.3, 10, 11, 19)
#'@export
ESg2d <-function(g, n1, n2, df)
{
  ESd <-(g*((sqrt(((n1 + n2)/df)))))
  return (setNames((list(ESd)), c("Cohen's d")))
}



