#' g from t-test for unequal sample size
#'
#'The t-value and sample sizes are used to compute the effect size. 
#'@param t     T-test value
#'@param n1    Sample size for group 1
#'@param n2    Sample size for group 2
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdT (-1.8, 100, 200)
#'@export
ESsmdT<-function (t, n1, n2) 
{
  ES <- t*(sqrt((n1 + n2)))/sqrt((n1*n2))
  Var <- ((n1 + n2)/(n1*n2) + ((ES^2)/(2*(n1+n2))))                      
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from t-test for equal sample size
#'
#'The t-value and total sample size are used to compute the effect size. 
#'@param t     T-test value
#'@param N     Total sample size of the study
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdT_2 (-1.8, 300)
#'@export
ESsmdT_2 <-function (t, N) 
{  ES <- (2*t)/(sqrt(N))
   Var <- 1/((N*(N-2))/(2*((t^2) + (2*N) -4)))
   return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from F-test for unequal sample size
#'
#'The F-value and sample sizes are used to compute the effect size. 
#'@param F     F-test value
#'@param n1    Sample size for group 1
#'@param n2    Sample size for group 2
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdF (4.06, 110, 120)
#'@export
ESsmdF <- function (F, n1, n2) 
{
  ES <- sqrt ((F*(n1+n2))/(n1*n2))
  Var <- ((n1 + n2)/(n1*n2) + ((ES^2)/(2*(n1+n2))))  
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from F-test for equal sample size
#'
#'The F-value and total sample size are used to compute the effect size. 
#'@param F     F-test value
#'@param N     Total sample size of the study
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdF_2 (4.06, 300)
#'@export
ESsmdF_2 <- function (F, N) 
{
  ES <- 2*(sqrt(F/N))
  Var <- ((N-1)/(N-3)*(4/N)*(1+((ES^2)/8)))
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from Chi-square test 
#'
#'The Chi-square value and total sample size are used to compute the effect size. 
#'@param  X2    Chi-square value
#'@param  N     Total sample size of the study
#'@return Effect size  (g)
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdX (3.841, 200)
#'@export
ESsmdX <- function (X2, N)  
{
  ES <- 2*(sqrt(X2/(N-X2)))
  Var <- (4 + (ES^2))/N
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from exact p-value from a t-test with equal sample size
#'
#' The exact p-value is used to estimate the t value. Then the t-value and sample size is used to compute the effect size.
#'@param pvalue    The reported exact p-value 
#'@param df        Degrees of freedom
#'@param N         Total sample size 
#'@param tail      Direction of the tail (1 = 1-tail, 2 = 2-tail, 3 = error)
#'@return Effect size  (g)
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdp (0.04, 98, 100, 2)
#'@export
ESsmdp <- function(pvalue, df, N, tail)
{
  if (tail == 1) {T<- qt(pvalue,df)}
  else if(tail == 2) {T <-qt(pvalue/2,df)}
  else {ES <-'Error'
        return (ES)}
  ES <- 2*T/(sqrt(N))
  Var <- 1/((N*(N-2))/(2*((T^2) + (2*N) -4)))
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from exact p-value from a t-test with unequal sample
#'
#' The exact p-value is used to estimate the t value. Then the t-value and sample size is used to compute the effect size.
#'@param pvalue    The reported exact p-value 
#'@param df        Degrees of freedom
#'@param n1        Sample size for group 1
#'@param n2        Sample size for group 2
#'@param tail      Direction of the tail (1 = 1-tail, 2 = 2-tail, 3 = error)
#'@return Effect size  (g)
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdp_2 (0.04, 198, 90, 110, 2)
#'@export
ESsmdp_2 <- function(pvalue, df, n1, n2, tail)
{
  if (tail == 1) {T<- qt(pvalue,df)}
  else if(tail == 2) {T <-qt(pvalue/2,df)}
  else {ES <-'Error'
        return (ES)}
  ES <- (T*(sqrt((n1 + n2))))/sqrt((n1*n2))
  Var <- ((n1 + n2)/(n1*n2) + ((ES^2)/(2*(n1+n2))))                      
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from means and standard errors of unequal sample
#'
#' The standard errors are used to estimate the pooled standard deviation. Then the means and pooled standard devaiton are used to compute the effect size.
#'@param m1     Mean of group 1
#'@param m2     Mean of group 2
#'@param n1     Sample size for group 1
#'@param n2     Sample size for group 2
#'@param se1    Standard error for group 1
#'@param se2    Standard error for group 2
#'@return Effect size  (g)
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmdE (50, 30, 100, 110, 10, 15)
#'@export
ESsmdE <-function (m1, m2, n1, n2, se1, se2)
{
  Sc <-(se1*(sqrt(n1-1)))
  St <-(se2*(sqrt(n2-1)))
  Sp <- sqrt((((n1-1)*(Sc^2)) + ((n2-1)*(St^2)))/((n1-1)+(n2-1)))
  ES <- (m1-m2)/Sp
  Var <- ((n1+n2)/(n1*n2)) + ((ES^2)/(2*(n1+n2)))
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

