#'g from One-way ANOVA given mean, sample sizes and standard deviations 
#'
#'The means, sample size and standard deviations are used to compute the effect size. 
#'@param m1     Mean for group 1
#'@param m2     Mean for group 2
#'@param sd1    Standard deviation for group 1
#'@param sd2    Standard deviation for group 2
#'@param n1     Sample size for group 1
#'@param n2     Sample size for group 2
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_Anova(8.02, 8.48, 2.26, 2.28, 102, 99)
#'@export
ESsmd_Anova <- function (m1, m2, sd1, sd2, n1, n2)
{
  MeanD <- m2-m1
  Sp <- sqrt((((n1-1)*(sd1^2))+((n2-1)*(sd2^2)))/(n1+n2-2))
  ES <- MeanD/Sp
  Var <-((n1 + n2)/(n1*n2) + ((ES^2)/(2*(n1+n2))))   
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#'g from One-way ANOVA given t-test value and sample sizes (post hoc results) 
#'
#'The t-value and sample sizes are used to compute the effect size.
#'@param t     t-test value from post-hoc test    
#'@param n1    Sample size for group 1
#'@param n2    Sample size for group 2
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_post(1.44, 102, 99)
#'@export
ESsmd_post <-function(t, n1, n2)
{
  ES <- t*sqrt(((1/n1)+ (1/n2)))
  Var <-((n1 + n2)/(n1*n2) + ((ES^2)/(2*(n1+n2)))) 
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#'g from One-way ANOVA given p-value and sample sizes (post hoc results) 
#'
#'The exact p-value and equal sample sizes are used to compute the effect size.
#'@param pvalue    The reported exact p-value 
#'@param df        Degrees of freedom
#'@param N         Total sample size 
#'@param tail      Direction of the tail (1 = 1-tail, 2 = 2-tail, 3 = error)
#'@return Effect size  (g)
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_postEP (0.11, 8, 10, 2)
#'@export
ESsmd_postEP <- function(pvalue, df, N, tail)
{
  if (tail == 1) {T<- qt(pvalue,df)}
  else if(tail == 2) {T <-qt(pvalue/2,df)}
  else {ES <-'Error'
  return (ES)}
  ES <- 2*T/(sqrt(N))
  Var <- 1/((N*(N-2))/(2*((T^2) + (2*N) -4)))
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#'g from One-way ANOVA given p-value and unequal sample sizes (post hoc results) 
#'
#' The exact p-value is used to estimate the t value. Then the t-value and sample size is used to compute the effect size.
#'@param pvalue    The reported exact p-value 
#'@param df        Degrees of freedom
#'@param n1        Sample size for group 1
#'@param n2        Sample size for group 2
#'@param tail      Direction of the tail (1 = 1-tail, 2 = 2-tail, 3 = error)
#'@return Effect size  (g)
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_postUEP (0.11, 8, 4, 6, 2)
#'@export
ESsmd_postUEP <- function(pvalue, df, n1, n2, tail)
{
  if (tail == 1) {T<- qt(pvalue,df)}
  else if(tail == 2) {T <-qt(pvalue/2,df)}
  else {ES <-'Error'
  return (ES)}
  ES <- (T*(sqrt((n1 + n2))))/sqrt((n1*n2))
  Var <- ((n1 + n2)/(n1*n2) + ((ES^2)/(2*(n1+n2))))                      
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#' g from One-way ANOVA given means, sample sizes and an overall F-test value 
#'
#' The means, sample sizes and overall F-value are used to estimate the pooled standard deviation. Then the means and pooled standard devaiton are used to compute the effect size.
#'@param m1       Mean for group 1
#'@param m2       Mean for group 2
#'@param m3       Mean for group 3
#'@param GM       Grand mean of the three groups
#'@param n1       Sample size for group 1
#'@param n2       Sample size for group 2
#'@param n3       Sample size for group 3
#'@param F        Overall F-test value
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_OF (8.02, 8.48, 8.24, 8.24, 102, 99, 99, 1.12)
#'GM = [((n1*m1)+ (n2*m2)) + (n3*m3)]/(n1+ n2+ n3)]
#'@export
ESsmd_OF <-function (m1, m2, m3, GM, n1, n2, n3, F)
{
  Sp <- sqrt((((n1*((m1-GM)^2))+(n2*((m2-GM)^2)) + (n3*((m3-GM)^2)))/2)/F)
  MeanD <-m2-m1
  ES <- MeanD/Sp
  Var <-((n1 + n2)/(n1 * n2) + ((ES^2)/(2*(n1 + n2)))) 
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}

#'g from One-way ANOVA given means, sample sizes and mean squares  
#'
#'The means and mean squares are used to compute the effect size. 
#'@param m1        Mean for group 1
#'@param m2        Mean for group 2
#'@param n1        Sample size for group 1
#'@param n2        Sample size for group 2
#'@param mswithin  Mean square within value
#'@return Effect size (g) 
#'@return Variance for the effect size (Var)
#'@examples
#'ESsmd_MS (8.02, 8.48, 102, 99, 4.77)
#'@export
ESsmd_MS <- function(m1, m2, n1, n2, mswithin)
{
  MeanD <-m2-m1
  Sp <-sqrt(mswithin)
  ES <- MeanD/Sp
  Var <- ((n1 + n2)/(n1 * n2) + ((ES^2)/(2*(n1 + n2))))
  return (setNames((list(ES, Var)),c("Effect size (Hedges's g)", "Variance")))
}
